
# q-expansion of newform 1336.2.a.c, downloaded from the LMFDB on 09 May 2024.

# We generate the q-expansion using the Hecke eigenvalues a_p at the primes.
# Each a_p is given as a linear combination
# of the following basis for the coefficient ring.

def make_data():

    from sage.all import prod, floor, prime_powers, gcd, QQ, primes_first_n, next_prime, RR

    def discrete_log(elts, gens, mod):
        # algorithm 2.2, page 16 of https://arxiv.org/abs/0903.2785
        def table_gens(gens, mod):
            T = [1]
            n = len(gens)
            r = [None]*n
            s = [None]*n
            for i in range(n):
                beta = gens[i]
                r[i] = 1
                N = len(T)
                while beta not in T:
                    for Tj in T[:N]:
                        T.append((beta*Tj) % mod)
                    beta = (beta*gens[i]) % mod
                    r[i] += 1
                s[i] = T.index(beta)
            return T, r, s
        T, r, s = table_gens(gens, mod)
        n = len(gens)
        N = [ prod(r[:j]) for j in range(n) ]
        Z = lambda s: [ (floor(s/N[j]) % r[j]) for j in range(n)]
        return [Z(T.index(elt % mod)) for elt in elts]
    def extend_multiplicatively(an):
        for pp in prime_powers(len(an)-1):
            for k in range(1, (len(an) - 1)//pp + 1):
                if gcd(k, pp) == 1:
                    an[pp*k] = an[pp]*an[k]
    from sage.all import PolynomialRing, NumberField, ZZ
    R = PolynomialRing(QQ, "x")
    f = R(poly_data)
    K = NumberField(f, "a")
    betas = [K([c/ZZ(den) for c in num]) for num, den in basis_data]
    convert_elt_to_field = lambda elt: sum(c*beta for c, beta in zip(elt, betas))
    # convert aps to K elements
    primes = primes_first_n(len(aps_data))
    good_primes = [p for p in primes if not p.divides(level)]
    aps = map(convert_elt_to_field, aps_data)
    if not hecke_ring_character_values:
        # trivial character
        char_values = dict(zip(good_primes, [1]*len(good_primes)))
    else:
        gens = [elt[0] for elt in hecke_ring_character_values]
        gens_values = [convert_elt_to_field(elt[1]) for elt in hecke_ring_character_values]
        char_values = dict([(
            p,prod(g**k for g, k in zip(gens_values, elt)))
            for p, elt in zip(good_primes, discrete_log(good_primes, gens, level))
            ])
    an_list_bound = next_prime(primes[-1])
    an = [0]*an_list_bound
    an[1] = 1
    
    from sage.all import PowerSeriesRing
    PS = PowerSeriesRing(K, "q")
    for p, ap in zip(primes, aps):
        if p.divides(level):
            euler_factor = [1, -ap]
        else:
            euler_factor = [1, -ap, p**(weight - 1) * char_values[p]]
        k = RR(an_list_bound).log(p).floor() + 1
        foo = (1/PS(euler_factor)).padded_list(k)
        for i in range(1, k):
            an[p**i] = foo[i]
    extend_multiplicatively(an)
    return PS(an)
level = 1336
weight = 2
poly_data = [1, 13, 2, -81, -15, 56, 8, -13, -1, 1]

# The entries in the following list give a basis for the
# coefficient ring in terms of a root of the defining polynomial above.
# Each line consists of the coefficients of the numerator, and a denominator.
basis_data  = [[[1, 0, 0, 0, 0, 0, 0, 0, 0], 1], [[0, 1, 0, 0, 0, 0, 0, 0, 0], 1], [[4, 3, -34, -31, 32, 16, -10, -2, 1], 2], [[-3, -5, 29, 31, -31, -16, 10, 2, -1], 1], [[-1, -34, 27, 92, -46, -42, 18, 5, -2], 2], [[-1, 5, 31, -137, 30, 72, -22, -9, 3], 2], [[5, -13, -33, 139, -30, -72, 22, 9, -3], 2], [[2, 19, -31, -84, 47, 41, -18, -5, 2], 1], [[-14, -41, 98, 199, -126, -98, 46, 12, -5], 2]]

hecke_ring_character_values = None
aps_data = [[0, 0, 0, 0, 0, 0, 0, 0, 0], [0, -1, 0, 0, 0, 0, 0, 0, 0], [-1, 0, -1, 0, 0, 0, 0, 0, -1], [0, 1, 0, 0, 1, 0, 0, 0, 0], [-1, 1, 0, 0, -1, -1, 0, -1, 0], [-1, 0, 1, -1, 0, 1, 1, 0, 2], [-1, 1, 0, 2, -1, -1, -2, -2, -1], [0, -1, 1, 0, -1, 1, 1, 2, 2], [0, 0, -2, 1, 0, 1, -2, 1, -1], [-3, -1, -1, -1, 1, 1, 4, 1, 2], [0, 2, 1, -2, 1, 0, 0, 0, 0], [-4, 1, 1, -1, 1, -2, -1, 0, -1], [-1, 0, 1, 0, 0, -2, -4, 0, -1], [0, -1, 1, 1, -1, 0, 1, 0, -1], [-1, 1, 0, 0, 1, -1, -1, 0, -3], [-3, -1, 0, -1, -1, 2, 1, 0, 0], [-2, -2, -2, 2, -2, 2, -1, -3, -4], [-4, -1, -2, 3, 2, -1, -3, 2, -3], [4, -3, 1, -3, -1, 2, 1, 0, 3], [-3, 2, -1, 3, 0, -1, 0, -3, -4], [-1, -1, 2, -2, 1, 1, 7, 5, 5], [-1, 0, 3, -2, 0, -2, -2, 0, 1], [-2, -1, 1, 1, -1, 0, 2, -1, 1], [-2, -4, 3, -2, -1, 1, 2, 2, 2], [1, -2, -1, -2, 0, 0, 3, 0, 2], [-5, 2, 3, -2, -2, 0, 6, -2, 1], [4, -1, -1, -2, 1, 1, 3, 3, 4], [0, -2, 1, -4, 0, -1, 1, 3, 2], [-4, -2, 0, 2, 2, -2, -6, 0, -4], [0, 1, 1, -1, -1, -2, -3, 0, 1], [2, -1, -1, 2, 3, -1, 3, -2, -1], [-1, -4, 3, 0, -2, 4, 4, 2, 3], [1, -1, 0, 4, -5, 1, -6, -5, -2], [1, -2, 1, 1, 0, -3, 2, 3, 4], [-6, 2, -4, 1, 4, -1, -1, 2, -1], [8, 0, -2, -1, 0, 1, 2, -1, 5], [-4, 3, 0, 1, 0, -2, 1, -4, -3], [5, -5, 2, 1, 1, 4, 3, 2, 2], [1, 0, 0, 0, 0, 0, 0, 0, 0], [1, -2, 1, 3, -2, 5, 1, 3, 3], [-1, 0, 3, -2, 4, -2, -3, -2, 1], [0, 3, -3, 2, 1, -1, -7, -2, -4], [-5, 2, 2, -1, -1, 1, 7, 2, 6], [0, 5, 3, -4, 1, -1, -1, -1, 0], [-7, 1, -4, 4, -1, -1, 3, -1, -1], [0, 7, 3, 1, -1, -6, -6, -4, -4], [-1, 3, -1, -4, 2, -3, 0, 0, -1], [5, 4, -2, 3, -3, -6, -9, -6, -8], [-5, 6, -7, 4, 4, -2, -5, -3, -3], [5, 1, 5, -4, -1, 6, -3, 1, 5], [-1, 3, 1, 2, -4, 3, -3, -1, -1], [-7, -5, -7, 4, -4, 2, -1, -1, -3], [2, 3, -3, -4, 3, -3, 5, 3, 4], [-1, -1, -7, 1, -1, 3, 1, -4, -2], [4, 3, -1, -2, -1, -3, -3, -5, -6], [-1, -2, -6, 2, 1, 1, 0, -4, -5], [-4, 1, -1, -2, 3, -3, -2, -2, -6], [4, 0, -8, 0, 2, 4, 3, 1, 0], [2, -2, 2, -1, -2, -1, 4, 5, 5], [1, -2, -4, 4, -3, -5, -9, -7, -5], [4, -2, -2, 3, -2, 1, -6, -2, -2], [-2, 2, -1, 6, -3, 0, -3, -3, -4], [3, -3, 2, 0, 3, 1, 1, 9, 9], [0, 5, 3, -3, 3, 0, -6, -1, 1], [7, 2, -5, 3, -2, -5, -7, 0, -6], [4, 2, 1, 1, 3, -2, -2, -1, 5], [4, -1, 7, -1, 3, 2, -6, 3, -3], [0, 0, -4, 3, -4, -1, -1, -1, -3], [-2, 5, 3, 0, 5, -1, 2, 2, 4], [-1, -8, 3, -4, 6, 4, 11, 7, 9], [3, 6, 0, 8, 0, -3, -9, -3, -7], [-1, -4, 2, -2, -1, 6, 1, 5, -1], [9, -1, -4, -6, 1, 7, 4, 1, 1], [-11, -3, 0, 0, -3, 5, 6, 2, 7], [2, -1, 3, 1, -1, 0, 0, 1, 3], [-6, 0, 1, -6, 8, 3, 12, 4, 6], [-4, 1, 7, -5, -1, 0, 3, 4, 11], [-1, -8, 2, -5, -5, 4, 4, 3, 10], [-2, 6, -2, 3, 4, -7, -6, -9, -11], [-1, -1, -4, 1, -1, -2, 1, -1, -7], [-11, 6, -4, 4, 1, -6, -6, -4, -1], [-3, -10, 4, -2, -2, 5, 6, 6, 5], [-10, 0, -1, 10, -3, -3, -8, -8, -6], [-6, 9, -1, -11, 5, 0, 9, 7, 7], [-1, 0, -1, 8, 0, -4, -2, -2, -1], [-2, -5, 1, -4, 7, -3, 10, 8, 6], [-1, 1, -8, 6, 1, 1, 8, -1, -1], [4, -1, -7, -2, -3, 1, 0, -6, -10], [4, -11, 9, 3, -3, 2, 3, 1, 7], [-1, -12, -5, 0, 2, 8, 9, 11, 3], [1, 7, 1, 4, -13, -2, -12, -8, -3], [-8, -2, -4, 4, -6, -4, -10, -8, -6], [14, -5, 5, 1, 5, 2, 4, 9, 1], [-6, 1, 1, -5, 1, 2, 9, 8, 5], [-9, -5, -6, 8, -5, -1, -10, -6, -7], [0, 2, 5, 1, 1, -6, 0, -3, 5], [-5, 5, -10, 9, 7, -4, -8, -4, -9], [-4, 12, -4, 4, -8, -4, -11, -7, -6], [1, 0, 0, -6, -1, -2, -9, 3, -7], [-12, 3, -1, -5, 5, 4, 10, 11, 7], [0, 6, -12, 7, 0, 1, -3, -12, -19], [-6, -3, -7, 2, -5, 1, 9, -4, -7], [-16, 5, 1, -1, -3, 2, 10, 4, 7], [-10, -3, 1, -1, 5, 4, -1, 6, -7], [4, 2, 4, -1, -6, 7, -7, -2, -1], [3, 6, 4, -9, -3, 1, 4, -1, 4], [3, 9, -4, 8, -1, 3, -4, -6, -3], [2, 3, 1, -3, 9, -2, -2, 7, -3], [-12, -16, 3, -5, 2, 2, 8, 11, 7], [9, -8, 4, -5, 4, 0, 1, 8, 4], [3, -6, 3, -5, 6, -3, -3, -2, 0], [-9, 6, 6, 1, -5, -5, -10, -1, 2], [2, -10, -5, -4, 0, 7, 5, 7, 4], [2, 6, 0, -6, 2, 4, 19, 1, 10], [0, -4, 3, 3, 1, 2, -9, 10, -1], [-7, -6, 7, -1, 0, 7, 2, 1, 6], [1, -2, 3, -9, 6, 1, 8, 13, 12], [11, -5, 0, -2, -1, 3, 12, 10, 9], [-11, 8, -8, -1, -1, -1, 0, 3, -6], [-12, 2, 8, 0, 0, 4, 1, 3, 10], [2, 0, -6, 7, -2, -3, 2, -3, 1], [-2, 10, -4, 0, 0, 0, -5, 3, -6], [-1, 11, -8, -3, 5, 2, 0, -7, -10], [3, -10, 3, -7, 2, 1, 2, 13, 14], [7, 12, -3, 4, -2, -6, -8, -14, -15], [-9, 2, 2, -6, -3, -3, -1, -5, 3], [-7, 12, 3, -3, -8, -5, 0, -9, -4], [-13, 8, 11, -3, 4, -7, -1, 0, -4], [4, 2, -2, 1, 6, -7, -4, -1, -5], [-7, 0, 3, 3, -2, -1, 6, -2, 6], [6, 6, 0, -9, 0, -3, 2, -1, 1], [-8, -2, -8, -1, -4, 1, 10, -5, -7], [-14, 7, -9, 3, 1, -2, 0, -7, -5], [-11, -3, 0, -1, 9, -2, 1, -3, -3], [-3, 1, 1, -4, 6, -2, -5, -1, 1], [2, 1, -3, 1, -7, -8, -5, -12, 3], [-2, 14, -2, 2, 2, -8, -17, -7, -4], [-2, -2, 6, -4, 2, 6, 11, 13, 4], [2, -1, -1, 13, -5, -4, -14, -15, -23], [-2, 9, -1, -7, 1, 0, 5, -3, 6], [5, -8, -1, -8, 2, 8, 16, 12, 11], [0, -4, -2, -5, 8, 9, 3, 8, 3], [22, -5, 9, -6, -3, -1, 8, 2, 4], [-3, 9, 2, 0, 5, 5, -4, 6, 3], [4, -4, 0, 2, 4, 6, -6, 4, -8], [6, -5, 0, 1, 2, -3, -16, 7, 1], [-11, 3, 10, -1, 7, -4, 3, 13, -1], [5, -11, 4, 7, -11, 6, 9, 1, 4], [-8, -7, 6, -5, -11, 7, 7, 0, 13], [8, -10, 4, 4, -10, -2, -5, -8, 3], [-13, -4, 7, -14, 6, -2, 13, 2, 9], [-13, -9, -4, 7, 3, 8, -3, 2, 0], [-5, -2, 2, -3, 8, 2, 12, 9, 0], [-6, -1, 5, 5, -1, -10, -6, -9, -1], [11, 4, 6, -2, -9, -11, -1, -5, 3], [-4, 0, 4, -3, 2, 9, 5, 1, 3], [-7, -7, 8, -5, 1, 2, 4, 8, 8], [-5, 2, 0, -5, -3, 5, 6, -7, -4], [0, 2, -16, 4, 2, 6, 2, -6, -10], [-5, -12, -3, -2, -6, 6, 14, 4, -1], [8, -11, -10, 10, 0, 0, -7, 7, -6], [13, 3, 4, -4, -1, 1, -6, 0, 3], [5, -6, -4, 7, -7, -7, -16, -13, -8], [14, 5, -1, 3, -5, -12, -19, -8, -7], [4, 3, 13, -8, 1, 5, 10, 2, 20], [6, 4, 20, -16, -2, -4, 5, 7, 14], [13, 15, -4, 5, 5, -6, -10, -3, -10], [15, 6, 6, -8, 6, 3, 2, 8, 9], [-9, -7, 0, 10, -13, 5, 3, -8, -8], [-8, 4, -9, 5, 0, 0, 13, -2, -7], [5, 1, -4, -7, 7, 6, 18, 7, 4], [3, -6, 11, -7, 2, 3, -5, 1, 1], [-3, 16, -3, 4, -10, -4, -10, -7, -14], [-5, 14, 2, -2, 3, 0, 12, 4, 1], [-15, 4, -17, 8, 2, 2, -3, -13, -25], [6, 0, 1, 6, -3, 2, 10, -14, -8], [-6, 14, -5, 0, 9, -14, -16, -14, -16], [-7, -3, 2, 3, -5, 6, 0, -9, -14], [-14, 3, 3, -6, 5, -5, -12, -1, -5], [-1, 3, 8, -6, -3, -9, 5, -3, 11], [19, 9, 2, -1, -7, -6, -8, -10, -14], [-8, 9, 8, -6, 4, 5, 8, 6, 18], [-13, -4, 3, -2, 10, 12, 13, 11, 9], [4, -7, 1, -2, 1, -7, 0, 0, -8], [4, -20, -2, 2, -12, 12, 16, 0, 0], [8, 4, -8, -7, -2, 5, 8, 7, 9], [2, 2, 3, -9, -5, -3, -8, 3, -5], [9, 3, -5, 5, -5, -9, -5, -14, 0], [14, 10, -5, 0, 12, -5, -13, 1, 0], [0, 7, -1, 11, 1, -10, -8, -9, -7], [17, 8, 3, -8, 4, 4, 6, 4, 19], [25, 14, 5, 4, 0, -6, -8, -8, 5], [2, 0, 3, 7, 7, -8, -11, 4, -11], [-3, -16, -10, 1, 0, 20, 15, 12, 14], [3, 11, -10, 4, -3, 1, -4, -17, -19], [4, 12, 0, 5, 2, -3, -8, -2, -13], [-8, 5, -3, 7, -7, -2, -7, -5, -17], [-20, 4, -9, 6, -1, -6, -9, -5, -6], [11, -1, 6, 2, -1, -9, -14, -1, -13], [5, -1, -9, 1, -2, -6, -17, -6, -16], [-12, 3, -1, 3, 5, -14, 1, -4, -3], [-3, 3, 17, -17, -6, -1, 10, 3, 18], [8, 6, 6, 0, 2, 10, -5, 11, 12], [-1, 4, 3, -4, 6, -2, -3, -5, 9], [24, -8, 8, 1, 6, 5, 2, 9, 11], [7, 4, -5, 8, 4, -8, -6, -1, -4], [3, -7, 10, -2, 1, -1, 8, 14, 23], [-7, 7, 0, -6, -3, -9, -10, -11, -7], [8, 9, 5, 0, 3, 1, -13, 9, 4], [7, 8, -20, 4, 0, 1, 2, -4, -15], [-10, -17, 1, 5, -3, 10, 10, 4, 12], [10, -12, -4, 10, -6, 6, -11, -2, -1], [4, 14, -2, 5, 0, 5, -3, 0, 1], [20, 12, 2, 0, 2, -10, 2, -14, -2], [7, 16, 10, 0, 14, -5, -3, 3, -3], [-7, 9, 3, 2, -1, -10, -11, -17, -21], [20, 2, 2, -12, 10, 10, 3, 11, 2], [13, 4, -1, -17, 6, 7, 18, 6, 17], [1, -4, 5, -8, -2, 12, 16, 9, 12], [2, 1, -9, 5, 1, -12, -4, -1, -3], [5, 0, 17, -2, 2, -4, -10, 8, 5], [12, 3, -6, -1, -4, 8, 11, -8, 5], [1, 2, -7, 3, -8, -7, -8, -15, -6], [4, 2, -8, 8, -18, -2, -19, -10, -8], [-6, 13, -15, -8, 3, -3, -4, 6, -18], [-12, 2, 5, 6, -5, -8, -4, 0, 2], [-9, -19, -2, -3, -5, 4, 10, 10, 4], [2, 15, 3, 3, -3, -2, 3, -12, 3], [16, 1, -5, 5, -9, -2, -3, -6, -9], [15, -5, 7, -15, 12, -3, 3, 14, 14], [-21, 6, -13, 12, -4, -10, -18, -24, -29], [-11, 0, 5, -2, 0, 6, 3, 5, 9], [17, -15, 22, -1, -1, 4, 2, 23, 28], [-13, -6, 3, -12, -2, 6, 18, 20, 27], [-9, -7, -10, 7, -3, -2, 10, -14, -11], [3, 6, -5, 7, -2, -13, -1, -4, -8], [-8, -12, 0, 5, -10, 3, 4, 1, 7], [-12, 15, -5, 3, -3, -4, -10, -14, -17], [-19, -2, -1, -9, 4, -5, -2, -7, -4], [4, 4, -14, -4, -4, 4, 5, -18, -13], [7, 12, 3, -6, -4, -4, -7, -5, -7], [4, -4, 10, 10, -4, -10, -5, -2, -6], [-14, 1, -13, 8, 11, -13, -11, -1, -24], [-18, -6, 10, -16, 6, 0, 19, 3, 16], [0, -8, 13, 4, -3, 7, -11, 3, 6], [14, 5, -10, -3, -3, -1, 13, 0, -3], [-2, -20, 2, -12, 10, 0, 9, 9, 2], [2, -9, 7, -11, -1, -8, -3, 6, 7], [-23, 14, -16, 6, 4, -3, -13, -5, -7], [-19, -10, -13, 20, -6, -10, -28, -8, -27], [-22, -3, 6, 7, 10, -11, -6, 3, -5], [-7, -11, -14, 2, 13, 13, 10, 11, -7], [6, 8, 4, 2, 4, -10, -20, -16, -4], [-6, -5, 3, 2, 9, -3, -16, 2, -10], [10, 1, 9, -3, -1, -14, -2, -11, -7], [-12, -12, 23, -1, 7, 7, 8, 3, 27], [-4, 8, -20, 12, 6, 0, -6, -12, -10], [25, -14, 6, -16, 7, 5, 6, 16, 15], [-9, 2, 3, 6, -2, 2, 10, 2, 9], [-10, -13, 19, -10, -7, 11, 11, 8, 18], [15, 0, 1, 11, 8, -7, -6, -3, -12], [-11, -19, -2, -1, 5, 14, 15, 10, 10], [8, -2, 8, -9, 6, 3, -2, 23, 13], [-1, -24, -5, -7, 0, 11, 15, 4, -4], [2, -4, 7, -2, 7, -6, -14, 10, 4], [-11, 14, -11, 4, 0, -6, -7, -3, -7], [-3, -9, 8, 9, 3, 4, -7, -2, 0], [-15, -16, 17, -6, 10, -2, 16, 14, 21], [11, -8, 3, 4, 2, 12, 1, 11, 5], [12, -13, 0, -4, 6, 4, 8, 12, 4], [12, -16, -6, 1, -4, 9, 12, 15, 9], [9, -8, -4, 14, -3, -6, -22, -10, -27], [-12, -14, 10, 0, -4, 12, 4, 14, 12], [-25, 2, 3, -4, 0, 2, -3, 1, -13], [-5, 20, -4, 8, 9, -11, -18, -12, -15], [14, -8, 20, -13, -8, -1, -4, 7, 17], [-4, -10, 6, -2, 0, -8, -7, 7, 0], [8, -16, -8, 10, -8, 4, -10, -16, -6], [-11, 13, -6, 16, -5, -3, -17, -17, -19], [-16, 6, 1, 5, -1, 11, 11, 4, 9], [19, 3, -2, 8, -5, -11, -15, -5, -5], [3, 17, -6, -5, -3, -4, -5, -6, 0], [-1, 5, -2, 4, 3, -11, 5, -3, -9], [-9, 22, -9, 7, 2, -3, -9, -7, -8], [-11, 1, -4, 11, -9, -12, -18, -13, -22], [13, 14, 3, -7, 2, 5, -7, -4, 2], [-6, -8, 15, -1, -1, 4, 0, 3, 13], [12, 19, 7, -1, -9, 2, -6, -15, 7], [3, -8, -11, 3, 0, 11, 4, 16, 13], [1, -10, -7, 3, -8, -1, 14, -9, 4], [-1, 12, -10, 8, 3, -12, -2, -8, -5], [3, 3, 20, -2, 1, -5, -18, -10, 1], [-11, 0, 0, 19, -6, -8, -16, -5, -8], [1, -14, 3, 5, -2, 3, 11, -14, -4], [-11, -20, -6, 7, 2, 14, -6, 5, 0], [24, -6, 8, -10, -4, 16, 19, 16, 26], [13, -10, -11, -5, 2, 13, 22, 14, -1], [27, -4, 3, 9, -2, -3, -14, -3, 10], [13, -27, -16, 13, 3, 12, 2, 13, 6], [23, 2, -11, -3, -6, 15, 9, 4, 6], [6, 18, 10, -11, 0, -5, -14, -17, -7], [14, -15, 9, -2, 7, 1, -2, 8, 10], [-21, -2, -14, 12, -9, 7, -15, -13, -11], [-23, -3, 4, -14, 5, 11, 18, 4, 27], [-23, -1, -2, 5, 5, -6, -11, -9, 2], [-20, -12, -14, 14, 2, -4, -3, 9, -2], [17, 20, 3, 1, -4, -1, 4, -15, 6], [9, -2, -10, 6, 4, -13, -1, -5, -19], [-6, 19, -3, 7, -3, -8, -8, -3, -11], [-27, 4, 7, -5, -6, -5, -12, 2, 3], [3, -8, 15, -11, -4, 3, 10, 3, 12], [-8, -12, 15, -16, -3, 0, 0, 10, 0], [-33, 5, 5, -11, 7, 3, 14, 9, 18], [-12, -6, -6, 6, -2, 2, 7, 9, 0], [-1, 10, -5, 2, -12, 8, -6, 2, 5], [4, 14, -2, -9, 12, -3, -12, 12, -11], [3, -16, -3, 10, 4, 2, -20, -6, -11], [-23, 6, 1, -3, -2, 3, 6, 18, 16], [-8, -16, -6, 8, -12, -2, -1, -3, 4], [9, -14, -1, -2, -18, 14, 10, 12, 21], [5, 1, 7, -20, 16, 0, 26, 14, 17], [-7, -8, 2, -8, 6, 5, 13, 15, 15], [10, 4, -15, -17, 17, 11, 24, 11, 15], [2, 23, -1, 11, -5, -8, -14, -5, -15], [-25, 11, 8, -9, 9, -8, -3, 0, -6], [-11, 20, -14, 4, 0, -15, -10, -8, -17], [-7, -5, 18, -10, -1, 7, 2, 2, 17], [-8, 15, 6, -8, 21, 10, 23, 11, 12], [-8, -8, 1, -15, 8, 18, 31, 16, 17], [4, -18, 0, 10, -4, 8, 1, 14, 9], [1, -7, 20, 3, 1, -2, 17, 7, 16], [-1, 14, 3, 5, -2, -25, -15, -9, -3], [-20, -8, -8, 19, -12, -3, -11, -6, -19], [7, -16, 9, 19, -16, -5, -18, -2, -11], [-25, 4, 7, -19, 2, 5, 20, 3, 6], [-33, -3, -16, 4, 3, -1, -6, -5, -23], [-5, -2, -9, -1, 8, 1, -24, 8, -16], [-10, -2, -16, 8, 10, 16, -1, 13, -24], [-2, 0, -6, -3, -6, 11, 11, 8, -5], [-9, -7, -4, 1, -1, -4, -6, -1, -4], [17, -15, -9, 7, -6, -3, -12, 9, 2], [2, 4, -17, 6, 3, -15, -20, -4, -22], [13, 4, -5, -13, -18, 3, 22, 1, 10], [-25, 4, 3, 0, 8, -12, -6, -14, -13], [7, 5, 7, -5, 2, -6, -11, 6, 10], [-20, 15, -5, -1, -3, -8, -9, -9, -6], [-6, -9, -10, 1, 5, 7, 12, -5, -7], [20, 8, -2, -8, 8, -8, 7, 2, 1], [11, 12, -17, 19, -2, 1, -32, -5, -16], [2, -7, 0, -2, 14, -7, 9, 3, 10], [42, -1, -9, 12, -5, -3, -21, -10, -5], [-22, -6, -2, -4, 8, 0, -11, 1, -10], [20, 9, -5, -7, 1, 6, 11, 8, 17], [5, 17, 0, -7, 7, 8, 12, 5, -4], [-8, -10, 20, -7, 2, 7, 19, 2, 23], [8, -14, 16, 1, 2, 3, 6, 21, 25], [-15, 17, -3, -3, -2, 4, -2, -11, -16], [-5, 18, -7, 15, 0, -9, 0, -11, -14], [6, -4, 12, 5, -16, -5, -8, 5, 13], [32, -12, -20, -3, -4, 9, 16, 4, 3], [-26, 12, -9, 8, -11, -9, -3, -9, -8], [-12, -2, -24, 15, 0, 5, 10, -3, -9], [24, -9, 25, -23, 7, -4, 8, 19, 23], [7, -13, 16, -15, -13, 10, 16, 0, 28], [0, -9, 7, 17, -11, 0, -23, -16, -17], [-1, -32, -3, 12, -16, 26, 10, -2, 7], [-11, 10, 19, -14, 10, 4, 8, 0, 7], [-17, -23, 10, -9, -3, 18, 12, 11, 14], [-14, 4, 21, 6, 1, -9, -20, -4, -10], [3, 5, 2, -3, 9, -16, 2, 17, 10], [-1, 1, -4, 3, -5, 2, 30, -15, 8], [0, -13, -6, 15, 3, -1, -7, 6, -15], [18, 16, 2, -3, -6, -7, -16, -10, -7], [-11, 3, 4, -12, 5, 1, 13, -5, -5], [-19, -10, 5, 4, 2, 0, -18, 18, -7], [-23, 5, -10, 25, -17, -2, -10, -9, -32], [-13, 2, 9, -6, 20, -6, -2, 6, 7], [0, -11, 0, -10, -3, -2, -6, -4, 10], [3, 2, -9, 15, -10, -9, -28, -7, -8], [9, -16, 14, -11, 3, -3, 13, 6, 20], [13, -1, 6, 3, -5, -8, 3, -27, -4], [23, -12, 7, -10, -6, -14, 3, -12, 1], [8, -13, -9, 6, 1, -13, 6, 4, -6], [6, -25, -3, -7, 19, 10, 5, 17, 3], [-27, -10, 21, -6, -2, 4, 14, 20, 23], [17, 6, -1, -4, -4, 6, 18, 2, 9], [9, -2, 5, 2, 2, 24, 17, 17, 19], [-16, -5, 13, -11, 9, -4, -9, -2, -11], [-49, 3, 11, -1, -7, -1, 14, -1, 4], [-11, -3, -4, 10, -7, -15, -2, -12, 5], [24, -10, 8, -5, -6, 3, 11, 12, 17], [19, -12, 9, -1, 6, 3, 22, 7, 14], [5, 32, 6, -6, -6, -13, 15, -5, 1], [31, -10, 7, -17, 10, 3, 9, 16, 6], [0, -15, -19, 11, -5, 0, 3, -12, -7], [15, 4, -11, 3, 4, -5, 5, -2, -10], [1, 2, -7, 15, -10, 9, 14, -10, -5], [-11, -17, -13, 11, -8, -3, -1, -12, -22], [-5, 8, -9, 6, -2, 4, 4, -10, -5], [7, 0, 7, -6, 0, 10, 15, 19, 13], [7, -22, 10, 11, -11, 4, -1, -2, 10], [-28, 16, -2, -14, 8, 2, 0, 10, 8], [-8, -20, 20, -18, -4, 14, 24, 8, 30], [8, 0, -2, -2, 0, 0, 1, -5, -14], [46, -2, 0, -11, 0, 1, 15, -2, 3], [-8, -6, 2, 12, -12, 0, 4, -10, 2], [1, -5, -22, 4, 19, 9, 19, 1, -15], [-9, -6, -5, -1, -4, -5, 17, 2, 8], [10, -2, 4, -6, 4, -2, -17, -3, -2], [-9, 6, -8, 5, 1, -9, -5, -4, -8], [7, 6, -15, -2, 4, 14, 8, 10, 17], [-1, 3, -4, -11, -3, 4, 8, 3, 14], [31, 10, -11, 2, -8, 8, -10, -1, 6], [27, 2, 14, 14, -11, -8, -30, 6, 3], [10, 25, -8, 13, 7, -7, -16, -9, -15], [4, 14, 15, 5, -13, -28, -27, -18, -15], [-43, -6, -5, -6, 6, 6, 12, 10, -11], [-9, -11, 0, 2, -9, -7, -12, -9, 3], [-14, 15, -11, -5, 21, -16, 0, -1, -17], [9, -15, 4, 1, -7, 0, -4, 0, 3], [10, 17, 17, -12, 9, -5, -16, -2, 0], [-4, -17, 15, 2, -7, 17, 9, 5, 12], [1, -22, 24, 10, -8, 13, -19, 5, 9], [18, 18, 24, 1, 4, -13, -27, 3, 10], [30, -19, -18, 15, -12, 21, 3, 0, 7], [44, -8, -14, -18, 16, 2, 11, 9, 2], [7, 8, -24, 29, 9, -19, -27, -14, -36], [-2, -12, 19, -5, 8, 4, -1, 22, 13], [-34, 2, -9, -4, 19, 11, 27, 13, 8], [29, -4, 15, -26, 0, 14, 30, 22, 27]]
